@@ -16,17 +16,17 @@ test_that("lawn_remove returns correct classes", {
 })
 
 test_that("property parameter works as expected", {
-  expect_lt(length(a$features$geometry$coordinates),
+  expect_gt(length(a$features$geometry$coordinates),
                    length(b$features$geometry$coordinates))
 })
 
 test_that("lawn_remove fails correctly", {
   # missing arguments
   expect_error(lawn_remove(), "argument \"features\" is missing, with no default")
-  # not found property param gives back same as input
-  expect_equal(unclass(lawn_remove(dat, 'stuff', '#0f0')), jsonlite::fromJSON(dat))
-  # not found value param gives back same as input
-  expect_equal(unclass(lawn_remove(dat, 'marker-color', '#zzz')), jsonlite::fromJSON(dat))
+  # not found property param gives back empty feature collection
+  expect_equal(length(unclass(lawn_remove(dat, 'stuff', '#0f0'))$features), 0)
+  # not found value param gives back empty feature collection
+  expect_equal(length(unclass(lawn_remove(dat, 'marker-color', '#zzz'))$features), 0)
   # can't pass in a character string to cellWidth
   expect_error(lawn_remove(lawn_point(c(4, 5)), 'marker-color', '#0f0', lint = TRUE),
                "Cannot read property 'length' of undefined")
